"""CylindricalGearManufacturingConfig"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, Union, Tuple

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal.python_net import python_net_import
from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy._internal.implicit import enum_with_selected_value, overridable
from mastapy.gears.manufacturing.cylindrical import _623, _624
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy.gears.analysis import _1221
from mastapy._internal.cast_exception import CastException

_DATABASE_WITH_SELECTED_ITEM = python_net_import(
    "SMT.MastaAPI.UtilityGUI.Databases", "DatabaseWithSelectedItem"
)
_CYLINDRICAL_GEAR_MANUFACTURING_CONFIG = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical", "CylindricalGearManufacturingConfig"
)

if TYPE_CHECKING:
    from mastapy.gears.gear_designs.cylindrical import _1012
    from mastapy.gears.manufacturing.cylindrical.cutters import _713
    from mastapy.gears.manufacturing.cylindrical.cutter_simulation import (
        _739,
        _742,
        _733,
    )
    from mastapy.gears.manufacturing.cylindrical.process_simulation import _639
    from mastapy.gears.gear_designs.cylindrical.thickness_stock_and_backlash import (
        _1089,
    )
    from mastapy.gears.manufacturing.cylindrical import _611
    from mastapy.gears.analysis import _1218, _1215


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearManufacturingConfig",)


Self = TypeVar("Self", bound="CylindricalGearManufacturingConfig")


class CylindricalGearManufacturingConfig(_1221.GearImplementationDetail):
    """CylindricalGearManufacturingConfig

    This is a mastapy class.
    """

    TYPE = _CYLINDRICAL_GEAR_MANUFACTURING_CONFIG
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_CylindricalGearManufacturingConfig")

    class _Cast_CylindricalGearManufacturingConfig:
        """Special nested class for casting CylindricalGearManufacturingConfig to subclasses."""

        def __init__(
            self: "CylindricalGearManufacturingConfig._Cast_CylindricalGearManufacturingConfig",
            parent: "CylindricalGearManufacturingConfig",
        ):
            self._parent = parent

        @property
        def gear_implementation_detail(
            self: "CylindricalGearManufacturingConfig._Cast_CylindricalGearManufacturingConfig",
        ) -> "_1221.GearImplementationDetail":
            return self._parent._cast(_1221.GearImplementationDetail)

        @property
        def gear_design_analysis(
            self: "CylindricalGearManufacturingConfig._Cast_CylindricalGearManufacturingConfig",
        ) -> "_1218.GearDesignAnalysis":
            from mastapy.gears.analysis import _1218

            return self._parent._cast(_1218.GearDesignAnalysis)

        @property
        def abstract_gear_analysis(
            self: "CylindricalGearManufacturingConfig._Cast_CylindricalGearManufacturingConfig",
        ) -> "_1215.AbstractGearAnalysis":
            from mastapy.gears.analysis import _1215

            return self._parent._cast(_1215.AbstractGearAnalysis)

        @property
        def cylindrical_gear_manufacturing_config(
            self: "CylindricalGearManufacturingConfig._Cast_CylindricalGearManufacturingConfig",
        ) -> "CylindricalGearManufacturingConfig":
            return self._parent

        def __getattr__(
            self: "CylindricalGearManufacturingConfig._Cast_CylindricalGearManufacturingConfig",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self, instance_to_wrap: "CylindricalGearManufacturingConfig.TYPE"
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def finish_cutter_database_selector(self: Self) -> "str":
        """str"""
        temp = self.wrapped.FinishCutterDatabaseSelector.SelectedItemName

        if temp is None:
            return ""

        return temp

    @finish_cutter_database_selector.setter
    @enforce_parameter_types
    def finish_cutter_database_selector(self: Self, value: "str"):
        self.wrapped.FinishCutterDatabaseSelector.SetSelectedItem(
            str(value) if value is not None else ""
        )

    @property
    def finishing_method(
        self: Self,
    ) -> (
        "enum_with_selected_value.EnumWithSelectedValue_CylindricalMftFinishingMethods"
    ):
        """EnumWithSelectedValue[mastapy.gears.manufacturing.cylindrical.CylindricalMftFinishingMethods]"""
        temp = self.wrapped.FinishingMethod

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_CylindricalMftFinishingMethods.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @finishing_method.setter
    @enforce_parameter_types
    def finishing_method(self: Self, value: "_623.CylindricalMftFinishingMethods"):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_CylindricalMftFinishingMethods.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.FinishingMethod = value

    @property
    def limiting_finish_depth_radius_mean(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LimitingFinishDepthRadiusMean

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_finish_depth_radius(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanFinishDepthRadius

        if temp is None:
            return 0.0

        return temp

    @property
    def minimum_finish_cutter_gear_root_clearance_factor(self: Self) -> "float":
        """float"""
        temp = self.wrapped.MinimumFinishCutterGearRootClearanceFactor

        if temp is None:
            return 0.0

        return temp

    @minimum_finish_cutter_gear_root_clearance_factor.setter
    @enforce_parameter_types
    def minimum_finish_cutter_gear_root_clearance_factor(self: Self, value: "float"):
        self.wrapped.MinimumFinishCutterGearRootClearanceFactor = (
            float(value) if value is not None else 0.0
        )

    @property
    def minimum_finish_depth_radius(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MinimumFinishDepthRadius

        if temp is None:
            return 0.0

        return temp

    @property
    def number_of_points_for_reporting_main_profile_finish_stock(
        self: Self,
    ) -> "overridable.Overridable_int":
        """Overridable[int]"""
        temp = self.wrapped.NumberOfPointsForReportingMainProfileFinishStock

        if temp is None:
            return 0

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.overridable", "Overridable_int"
        )(temp)

    @number_of_points_for_reporting_main_profile_finish_stock.setter
    @enforce_parameter_types
    def number_of_points_for_reporting_main_profile_finish_stock(
        self: Self, value: "Union[int, Tuple[int, bool]]"
    ):
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0, is_overridden
        )
        self.wrapped.NumberOfPointsForReportingMainProfileFinishStock = value

    @property
    def rough_cutter_database_selector(self: Self) -> "str":
        """str"""
        temp = self.wrapped.RoughCutterDatabaseSelector.SelectedItemName

        if temp is None:
            return ""

        return temp

    @rough_cutter_database_selector.setter
    @enforce_parameter_types
    def rough_cutter_database_selector(self: Self, value: "str"):
        self.wrapped.RoughCutterDatabaseSelector.SetSelectedItem(
            str(value) if value is not None else ""
        )

    @property
    def roughing_method(
        self: Self,
    ) -> "enum_with_selected_value.EnumWithSelectedValue_CylindricalMftRoughingMethods":
        """EnumWithSelectedValue[mastapy.gears.manufacturing.cylindrical.CylindricalMftRoughingMethods]"""
        temp = self.wrapped.RoughingMethod

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_CylindricalMftRoughingMethods.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @roughing_method.setter
    @enforce_parameter_types
    def roughing_method(self: Self, value: "_624.CylindricalMftRoughingMethods"):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_CylindricalMftRoughingMethods.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.RoughingMethod = value

    @property
    def design(self: Self) -> "_1012.CylindricalGearDesign":
        """mastapy.gears.gear_designs.cylindrical.CylindricalGearDesign

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Design

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def finish_cutter(self: Self) -> "_713.CylindricalGearRealCutterDesign":
        """mastapy.gears.manufacturing.cylindrical.cutters.CylindricalGearRealCutterDesign

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FinishCutter

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def finish_cutter_simulation(self: Self) -> "_739.GearCutterSimulation":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.GearCutterSimulation

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FinishCutterSimulation

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def finish_manufacturing_process_controls(
        self: Self,
    ) -> "_742.ManufacturingProcessControls":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.ManufacturingProcessControls

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FinishManufacturingProcessControls

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def finish_process_simulation(self: Self) -> "_639.CutterProcessSimulation":
        """mastapy.gears.manufacturing.cylindrical.process_simulation.CutterProcessSimulation

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FinishProcessSimulation

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def finish_stock_specification(self: Self) -> "_1089.FinishStockSpecification":
        """mastapy.gears.gear_designs.cylindrical.thickness_stock_and_backlash.FinishStockSpecification

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FinishStockSpecification

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def finished_gear_specification(self: Self) -> "_733.CylindricalGearSpecification":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.CylindricalGearSpecification

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FinishedGearSpecification

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def gear_blank(self: Self) -> "_611.CylindricalGearBlank":
        """mastapy.gears.manufacturing.cylindrical.CylindricalGearBlank

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearBlank

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def rough_cutter(self: Self) -> "_713.CylindricalGearRealCutterDesign":
        """mastapy.gears.manufacturing.cylindrical.cutters.CylindricalGearRealCutterDesign

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RoughCutter

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def rough_cutter_simulation(self: Self) -> "_739.GearCutterSimulation":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.GearCutterSimulation

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RoughCutterSimulation

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def rough_gear_specification(self: Self) -> "_733.CylindricalGearSpecification":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.CylindricalGearSpecification

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RoughGearSpecification

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def rough_manufacturing_process_controls(
        self: Self,
    ) -> "_742.ManufacturingProcessControls":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.ManufacturingProcessControls

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RoughManufacturingProcessControls

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def rough_process_simulation(self: Self) -> "_639.CutterProcessSimulation":
        """mastapy.gears.manufacturing.cylindrical.process_simulation.CutterProcessSimulation

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RoughProcessSimulation

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    def create_new_finish_cutter_compatible_with_gear_in_design_mode(self: Self):
        """Method does not return."""
        self.wrapped.CreateNewFinishCutterCompatibleWithGearInDesignMode()

    def create_new_rough_cutter_compatible_with_gear_in_design_mode(self: Self):
        """Method does not return."""
        self.wrapped.CreateNewRoughCutterCompatibleWithGearInDesignMode()

    @property
    def cast_to(
        self: Self,
    ) -> "CylindricalGearManufacturingConfig._Cast_CylindricalGearManufacturingConfig":
        return self._Cast_CylindricalGearManufacturingConfig(self)



"""CylindricalGearShaperTangible"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor
from mastapy.gears.manufacturing.cylindrical.cutters.tangibles import _723
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_SHAPER_TANGIBLE = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.Cutters.Tangibles",
    "CylindricalGearShaperTangible",
)

if TYPE_CHECKING:
    from mastapy.gears.manufacturing.cylindrical.cutters import _714


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearShaperTangible",)


Self = TypeVar("Self", bound="CylindricalGearShaperTangible")


class CylindricalGearShaperTangible(_723.CutterShapeDefinition):
    """CylindricalGearShaperTangible

    This is a mastapy class.
    """

    TYPE = _CYLINDRICAL_GEAR_SHAPER_TANGIBLE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_CylindricalGearShaperTangible")

    class _Cast_CylindricalGearShaperTangible:
        """Special nested class for casting CylindricalGearShaperTangible to subclasses."""

        def __init__(
            self: "CylindricalGearShaperTangible._Cast_CylindricalGearShaperTangible",
            parent: "CylindricalGearShaperTangible",
        ):
            self._parent = parent

        @property
        def cutter_shape_definition(
            self: "CylindricalGearShaperTangible._Cast_CylindricalGearShaperTangible",
        ) -> "_723.CutterShapeDefinition":
            return self._parent._cast(_723.CutterShapeDefinition)

        @property
        def cylindrical_gear_shaper_tangible(
            self: "CylindricalGearShaperTangible._Cast_CylindricalGearShaperTangible",
        ) -> "CylindricalGearShaperTangible":
            return self._parent

        def __getattr__(
            self: "CylindricalGearShaperTangible._Cast_CylindricalGearShaperTangible",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "CylindricalGearShaperTangible.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def actual_protuberance(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ActualProtuberance

        if temp is None:
            return 0.0

        return temp

    @property
    def base_diameter(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BaseDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def edge_radius(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EdgeRadius

        if temp is None:
            return 0.0

        return temp

    @property
    def helix_angle(self: Self) -> "float":
        """float"""
        temp = self.wrapped.HelixAngle

        if temp is None:
            return 0.0

        return temp

    @helix_angle.setter
    @enforce_parameter_types
    def helix_angle(self: Self, value: "float"):
        self.wrapped.HelixAngle = float(value) if value is not None else 0.0

    @property
    def maximum_blade_control_distance(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumBladeControlDistance

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_protuberance(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumProtuberance

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_protuberance_height_for_single_circle(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumProtuberanceHeightForSingleCircle

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_tip_control_distance_for_zero_protuberance(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumTipControlDistanceForZeroProtuberance

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_tip_diameter_to_avoid_pointed_teeth_no_protuberance(
        self: Self,
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumTipDiameterToAvoidPointedTeethNoProtuberance

        if temp is None:
            return 0.0

        return temp

    @property
    def minimum_protuberance_having_pointed_teeth(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MinimumProtuberanceHavingPointedTeeth

        if temp is None:
            return 0.0

        return temp

    @property
    def minimum_protuberance_height_for_single_circle(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MinimumProtuberanceHeightForSingleCircle

        if temp is None:
            return 0.0

        return temp

    @property
    def normal_tooth_thickness(self: Self) -> "float":
        """float"""
        temp = self.wrapped.NormalToothThickness

        if temp is None:
            return 0.0

        return temp

    @normal_tooth_thickness.setter
    @enforce_parameter_types
    def normal_tooth_thickness(self: Self, value: "float"):
        self.wrapped.NormalToothThickness = float(value) if value is not None else 0.0

    @property
    def protuberance(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Protuberance

        if temp is None:
            return 0.0

        return temp

    @protuberance.setter
    @enforce_parameter_types
    def protuberance(self: Self, value: "float"):
        self.wrapped.Protuberance = float(value) if value is not None else 0.0

    @property
    def protuberance_angle(self: Self) -> "float":
        """float"""
        temp = self.wrapped.ProtuberanceAngle

        if temp is None:
            return 0.0

        return temp

    @protuberance_angle.setter
    @enforce_parameter_types
    def protuberance_angle(self: Self, value: "float"):
        self.wrapped.ProtuberanceAngle = float(value) if value is not None else 0.0

    @property
    def protuberance_height(self: Self) -> "float":
        """float"""
        temp = self.wrapped.ProtuberanceHeight

        if temp is None:
            return 0.0

        return temp

    @protuberance_height.setter
    @enforce_parameter_types
    def protuberance_height(self: Self, value: "float"):
        self.wrapped.ProtuberanceHeight = float(value) if value is not None else 0.0

    @property
    def root_diameter(self: Self) -> "float":
        """float"""
        temp = self.wrapped.RootDiameter

        if temp is None:
            return 0.0

        return temp

    @root_diameter.setter
    @enforce_parameter_types
    def root_diameter(self: Self, value: "float"):
        self.wrapped.RootDiameter = float(value) if value is not None else 0.0

    @property
    def semi_topping_diameter(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SemiToppingDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def semi_topping_pressure_angle(self: Self) -> "float":
        """float"""
        temp = self.wrapped.SemiToppingPressureAngle

        if temp is None:
            return 0.0

        return temp

    @semi_topping_pressure_angle.setter
    @enforce_parameter_types
    def semi_topping_pressure_angle(self: Self, value: "float"):
        self.wrapped.SemiToppingPressureAngle = (
            float(value) if value is not None else 0.0
        )

    @property
    def single_circle_maximum_edge_radius(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SingleCircleMaximumEdgeRadius

        if temp is None:
            return 0.0

        return temp

    @property
    def tip_diameter(self: Self) -> "float":
        """float"""
        temp = self.wrapped.TipDiameter

        if temp is None:
            return 0.0

        return temp

    @tip_diameter.setter
    @enforce_parameter_types
    def tip_diameter(self: Self, value: "float"):
        self.wrapped.TipDiameter = float(value) if value is not None else 0.0

    @property
    def tip_thickness(self: Self) -> "float":
        """float"""
        temp = self.wrapped.TipThickness

        if temp is None:
            return 0.0

        return temp

    @tip_thickness.setter
    @enforce_parameter_types
    def tip_thickness(self: Self, value: "float"):
        self.wrapped.TipThickness = float(value) if value is not None else 0.0

    @property
    def design(self: Self) -> "_714.CylindricalGearShaper":
        """mastapy.gears.manufacturing.cylindrical.cutters.CylindricalGearShaper

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Design

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "CylindricalGearShaperTangible._Cast_CylindricalGearShaperTangible":
        return self._Cast_CylindricalGearShaperTangible(self)



"""GearImplementationAnalysisDutyCycle"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy.gears.analysis import _1218
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_GEAR_IMPLEMENTATION_ANALYSIS_DUTY_CYCLE = python_net_import(
    "SMT.MastaAPI.Gears.Analysis", "GearImplementationAnalysisDutyCycle"
)

if TYPE_CHECKING:
    from mastapy.gears.manufacturing.cylindrical import _616
    from mastapy.gears.analysis import _1215


__docformat__ = "restructuredtext en"
__all__ = ("GearImplementationAnalysisDutyCycle",)


Self = TypeVar("Self", bound="GearImplementationAnalysisDutyCycle")


class GearImplementationAnalysisDutyCycle(_1218.GearDesignAnalysis):
    """GearImplementationAnalysisDutyCycle

    This is a mastapy class.
    """

    TYPE = _GEAR_IMPLEMENTATION_ANALYSIS_DUTY_CYCLE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_GearImplementationAnalysisDutyCycle")

    class _Cast_GearImplementationAnalysisDutyCycle:
        """Special nested class for casting GearImplementationAnalysisDutyCycle to subclasses."""

        def __init__(
            self: "GearImplementationAnalysisDutyCycle._Cast_GearImplementationAnalysisDutyCycle",
            parent: "GearImplementationAnalysisDutyCycle",
        ):
            self._parent = parent

        @property
        def gear_design_analysis(
            self: "GearImplementationAnalysisDutyCycle._Cast_GearImplementationAnalysisDutyCycle",
        ) -> "_1218.GearDesignAnalysis":
            return self._parent._cast(_1218.GearDesignAnalysis)

        @property
        def abstract_gear_analysis(
            self: "GearImplementationAnalysisDutyCycle._Cast_GearImplementationAnalysisDutyCycle",
        ) -> "_1215.AbstractGearAnalysis":
            from mastapy.gears.analysis import _1215

            return self._parent._cast(_1215.AbstractGearAnalysis)

        @property
        def cylindrical_manufactured_gear_duty_cycle(
            self: "GearImplementationAnalysisDutyCycle._Cast_GearImplementationAnalysisDutyCycle",
        ) -> "_616.CylindricalManufacturedGearDutyCycle":
            from mastapy.gears.manufacturing.cylindrical import _616

            return self._parent._cast(_616.CylindricalManufacturedGearDutyCycle)

        @property
        def gear_implementation_analysis_duty_cycle(
            self: "GearImplementationAnalysisDutyCycle._Cast_GearImplementationAnalysisDutyCycle",
        ) -> "GearImplementationAnalysisDutyCycle":
            return self._parent

        def __getattr__(
            self: "GearImplementationAnalysisDutyCycle._Cast_GearImplementationAnalysisDutyCycle",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self, instance_to_wrap: "GearImplementationAnalysisDutyCycle.TYPE"
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def cast_to(
        self: Self,
    ) -> (
        "GearImplementationAnalysisDutyCycle._Cast_GearImplementationAnalysisDutyCycle"
    ):
        return self._Cast_GearImplementationAnalysisDutyCycle(self)



"""ElectricMachineHarmonicLoadData"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import enum_with_selected_value_runtime, conversion
from mastapy._internal.implicit import enum_with_selected_value
from mastapy.electric_machines.harmonic_load_data import _1381, _1377
from mastapy.system_model.analyses_and_results.static_loads import _6977
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_ELECTRIC_MACHINE_HARMONIC_LOAD_DATA = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads",
    "ElectricMachineHarmonicLoadData",
)

if TYPE_CHECKING:
    from mastapy.math_utility import _1512
    from mastapy.system_model.analyses_and_results.static_loads import (
        _6873,
        _6874,
        _6875,
        _6876,
        _6877,
        _6878,
    )
    from mastapy.electric_machines.harmonic_load_data import _1382, _1379


__docformat__ = "restructuredtext en"
__all__ = ("ElectricMachineHarmonicLoadData",)


Self = TypeVar("Self", bound="ElectricMachineHarmonicLoadData")


class ElectricMachineHarmonicLoadData(_1377.ElectricMachineHarmonicLoadDataBase):
    """ElectricMachineHarmonicLoadData

    This is a mastapy class.
    """

    TYPE = _ELECTRIC_MACHINE_HARMONIC_LOAD_DATA
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_ElectricMachineHarmonicLoadData")

    class _Cast_ElectricMachineHarmonicLoadData:
        """Special nested class for casting ElectricMachineHarmonicLoadData to subclasses."""

        def __init__(
            self: "ElectricMachineHarmonicLoadData._Cast_ElectricMachineHarmonicLoadData",
            parent: "ElectricMachineHarmonicLoadData",
        ):
            self._parent = parent

        @property
        def electric_machine_harmonic_load_data_base(
            self: "ElectricMachineHarmonicLoadData._Cast_ElectricMachineHarmonicLoadData",
        ) -> "_1377.ElectricMachineHarmonicLoadDataBase":
            return self._parent._cast(_1377.ElectricMachineHarmonicLoadDataBase)

        @property
        def speed_dependent_harmonic_load_data(
            self: "ElectricMachineHarmonicLoadData._Cast_ElectricMachineHarmonicLoadData",
        ) -> "_1382.SpeedDependentHarmonicLoadData":
            from mastapy.electric_machines.harmonic_load_data import _1382

            return self._parent._cast(_1382.SpeedDependentHarmonicLoadData)

        @property
        def harmonic_load_data_base(
            self: "ElectricMachineHarmonicLoadData._Cast_ElectricMachineHarmonicLoadData",
        ) -> "_1379.HarmonicLoadDataBase":
            from mastapy.electric_machines.harmonic_load_data import _1379

            return self._parent._cast(_1379.HarmonicLoadDataBase)

        @property
        def electric_machine_harmonic_load_data_from_excel(
            self: "ElectricMachineHarmonicLoadData._Cast_ElectricMachineHarmonicLoadData",
        ) -> "_6873.ElectricMachineHarmonicLoadDataFromExcel":
            from mastapy.system_model.analyses_and_results.static_loads import _6873

            return self._parent._cast(_6873.ElectricMachineHarmonicLoadDataFromExcel)

        @property
        def electric_machine_harmonic_load_data_from_flux(
            self: "ElectricMachineHarmonicLoadData._Cast_ElectricMachineHarmonicLoadData",
        ) -> "_6874.ElectricMachineHarmonicLoadDataFromFlux":
            from mastapy.system_model.analyses_and_results.static_loads import _6874

            return self._parent._cast(_6874.ElectricMachineHarmonicLoadDataFromFlux)

        @property
        def electric_machine_harmonic_load_data_from_jmag(
            self: "ElectricMachineHarmonicLoadData._Cast_ElectricMachineHarmonicLoadData",
        ) -> "_6875.ElectricMachineHarmonicLoadDataFromJMAG":
            from mastapy.system_model.analyses_and_results.static_loads import _6875

            return self._parent._cast(_6875.ElectricMachineHarmonicLoadDataFromJMAG)

        @property
        def electric_machine_harmonic_load_data_from_masta(
            self: "ElectricMachineHarmonicLoadData._Cast_ElectricMachineHarmonicLoadData",
        ) -> "_6876.ElectricMachineHarmonicLoadDataFromMASTA":
            from mastapy.system_model.analyses_and_results.static_loads import _6876

            return self._parent._cast(_6876.ElectricMachineHarmonicLoadDataFromMASTA)

        @property
        def electric_machine_harmonic_load_data_from_motor_cad(
            self: "ElectricMachineHarmonicLoadData._Cast_ElectricMachineHarmonicLoadData",
        ) -> "_6877.ElectricMachineHarmonicLoadDataFromMotorCAD":
            from mastapy.system_model.analyses_and_results.static_loads import _6877

            return self._parent._cast(_6877.ElectricMachineHarmonicLoadDataFromMotorCAD)

        @property
        def electric_machine_harmonic_load_data_from_motor_packages(
            self: "ElectricMachineHarmonicLoadData._Cast_ElectricMachineHarmonicLoadData",
        ) -> "_6878.ElectricMachineHarmonicLoadDataFromMotorPackages":
            from mastapy.system_model.analyses_and_results.static_loads import _6878

            return self._parent._cast(
                _6878.ElectricMachineHarmonicLoadDataFromMotorPackages
            )

        @property
        def electric_machine_harmonic_load_data(
            self: "ElectricMachineHarmonicLoadData._Cast_ElectricMachineHarmonicLoadData",
        ) -> "ElectricMachineHarmonicLoadData":
            return self._parent

        def __getattr__(
            self: "ElectricMachineHarmonicLoadData._Cast_ElectricMachineHarmonicLoadData",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "ElectricMachineHarmonicLoadData.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def apply_to_all_data_types(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.ApplyToAllDataTypes

        if temp is None:
            return False

        return temp

    @apply_to_all_data_types.setter
    @enforce_parameter_types
    def apply_to_all_data_types(self: Self, value: "bool"):
        self.wrapped.ApplyToAllDataTypes = bool(value) if value is not None else False

    @property
    def apply_to_all_speeds_for_selected_data_type(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.ApplyToAllSpeedsForSelectedDataType

        if temp is None:
            return False

        return temp

    @apply_to_all_speeds_for_selected_data_type.setter
    @enforce_parameter_types
    def apply_to_all_speeds_for_selected_data_type(self: Self, value: "bool"):
        self.wrapped.ApplyToAllSpeedsForSelectedDataType = (
            bool(value) if value is not None else False
        )

    @property
    def constant_torque(self: Self) -> "float":
        """float"""
        temp = self.wrapped.ConstantTorque

        if temp is None:
            return 0.0

        return temp

    @constant_torque.setter
    @enforce_parameter_types
    def constant_torque(self: Self, value: "float"):
        self.wrapped.ConstantTorque = float(value) if value is not None else 0.0

    @property
    def data_type_for_scaling(
        self: Self,
    ) -> "enum_with_selected_value.EnumWithSelectedValue_HarmonicLoadDataType":
        """EnumWithSelectedValue[mastapy.electric_machines.harmonic_load_data.HarmonicLoadDataType]"""
        temp = self.wrapped.DataTypeForScaling

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_HarmonicLoadDataType.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @data_type_for_scaling.setter
    @enforce_parameter_types
    def data_type_for_scaling(self: Self, value: "_1381.HarmonicLoadDataType"):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_HarmonicLoadDataType.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.DataTypeForScaling = value

    @property
    def rotor_moment_from_stator_teeth_axial_loads_amplitude_cut_off(
        self: Self,
    ) -> "float":
        """float"""
        temp = self.wrapped.RotorMomentFromStatorTeethAxialLoadsAmplitudeCutOff

        if temp is None:
            return 0.0

        return temp

    @rotor_moment_from_stator_teeth_axial_loads_amplitude_cut_off.setter
    @enforce_parameter_types
    def rotor_moment_from_stator_teeth_axial_loads_amplitude_cut_off(
        self: Self, value: "float"
    ):
        self.wrapped.RotorMomentFromStatorTeethAxialLoadsAmplitudeCutOff = (
            float(value) if value is not None else 0.0
        )

    @property
    def rotor_x_force_amplitude_cut_off(self: Self) -> "float":
        """float"""
        temp = self.wrapped.RotorXForceAmplitudeCutOff

        if temp is None:
            return 0.0

        return temp

    @rotor_x_force_amplitude_cut_off.setter
    @enforce_parameter_types
    def rotor_x_force_amplitude_cut_off(self: Self, value: "float"):
        self.wrapped.RotorXForceAmplitudeCutOff = (
            float(value) if value is not None else 0.0
        )

    @property
    def rotor_y_force_amplitude_cut_off(self: Self) -> "float":
        """float"""
        temp = self.wrapped.RotorYForceAmplitudeCutOff

        if temp is None:
            return 0.0

        return temp

    @rotor_y_force_amplitude_cut_off.setter
    @enforce_parameter_types
    def rotor_y_force_amplitude_cut_off(self: Self, value: "float"):
        self.wrapped.RotorYForceAmplitudeCutOff = (
            float(value) if value is not None else 0.0
        )

    @property
    def rotor_z_force_amplitude_cut_off(self: Self) -> "float":
        """float"""
        temp = self.wrapped.RotorZForceAmplitudeCutOff

        if temp is None:
            return 0.0

        return temp

    @rotor_z_force_amplitude_cut_off.setter
    @enforce_parameter_types
    def rotor_z_force_amplitude_cut_off(self: Self, value: "float"):
        self.wrapped.RotorZForceAmplitudeCutOff = (
            float(value) if value is not None else 0.0
        )

    @property
    def scale(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Scale

        if temp is None:
            return 0.0

        return temp

    @scale.setter
    @enforce_parameter_types
    def scale(self: Self, value: "float"):
        self.wrapped.Scale = float(value) if value is not None else 0.0

    @property
    def torque_ripple_amplitude_cut_off(self: Self) -> "float":
        """float"""
        temp = self.wrapped.TorqueRippleAmplitudeCutOff

        if temp is None:
            return 0.0

        return temp

    @torque_ripple_amplitude_cut_off.setter
    @enforce_parameter_types
    def torque_ripple_amplitude_cut_off(self: Self, value: "float"):
        self.wrapped.TorqueRippleAmplitudeCutOff = (
            float(value) if value is not None else 0.0
        )

    @property
    def torque_ripple_input_type(
        self: Self,
    ) -> "enum_with_selected_value.EnumWithSelectedValue_TorqueRippleInputType":
        """EnumWithSelectedValue[mastapy.system_model.analyses_and_results.static_loads.TorqueRippleInputType]"""
        temp = self.wrapped.TorqueRippleInputType

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_TorqueRippleInputType.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @torque_ripple_input_type.setter
    @enforce_parameter_types
    def torque_ripple_input_type(self: Self, value: "_6977.TorqueRippleInputType"):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_TorqueRippleInputType.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.TorqueRippleInputType = value

    @property
    def use_stator_radius_from_masta_model(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.UseStatorRadiusFromMASTAModel

        if temp is None:
            return False

        return temp

    @use_stator_radius_from_masta_model.setter
    @enforce_parameter_types
    def use_stator_radius_from_masta_model(self: Self, value: "bool"):
        self.wrapped.UseStatorRadiusFromMASTAModel = (
            bool(value) if value is not None else False
        )

    @property
    def excitations(self: Self) -> "List[_1512.FourierSeries]":
        """List[mastapy.math_utility.FourierSeries]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Excitations

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: Self,
    ) -> "ElectricMachineHarmonicLoadData._Cast_ElectricMachineHarmonicLoadData":
        return self._Cast_ElectricMachineHarmonicLoadData(self)



"""AssemblyCompoundStabilityAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.stability_analyses.compound import _3897
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_ASSEMBLY_COMPOUND_STABILITY_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StabilityAnalyses.Compound",
    "AssemblyCompoundStabilityAnalysis",
)

if TYPE_CHECKING:
    from mastapy.system_model.part_model import _2433
    from mastapy.system_model.analyses_and_results.stability_analyses import _3770
    from mastapy.system_model.analyses_and_results.stability_analyses.compound import (
        _3905,
        _3907,
        _3910,
        _3917,
        _3916,
        _3938,
        _3918,
        _3923,
        _3928,
        _3940,
        _3942,
        _3946,
        _3953,
        _3952,
        _3954,
        _3961,
        _3968,
        _3971,
        _3972,
        _3973,
        _3975,
        _3977,
        _3982,
        _3983,
        _3984,
        _3986,
        _3988,
        _3993,
        _3992,
        _3998,
        _3999,
        _4004,
        _4007,
        _4010,
        _4014,
        _4018,
        _4022,
        _4025,
        _3991,
        _3976,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import _7546, _7543
    from mastapy.system_model.analyses_and_results import _2651


__docformat__ = "restructuredtext en"
__all__ = ("AssemblyCompoundStabilityAnalysis",)


Self = TypeVar("Self", bound="AssemblyCompoundStabilityAnalysis")


class AssemblyCompoundStabilityAnalysis(
    _3897.AbstractAssemblyCompoundStabilityAnalysis
):
    """AssemblyCompoundStabilityAnalysis

    This is a mastapy class.
    """

    TYPE = _ASSEMBLY_COMPOUND_STABILITY_ANALYSIS
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_AssemblyCompoundStabilityAnalysis")

    class _Cast_AssemblyCompoundStabilityAnalysis:
        """Special nested class for casting AssemblyCompoundStabilityAnalysis to subclasses."""

        def __init__(
            self: "AssemblyCompoundStabilityAnalysis._Cast_AssemblyCompoundStabilityAnalysis",
            parent: "AssemblyCompoundStabilityAnalysis",
        ):
            self._parent = parent

        @property
        def abstract_assembly_compound_stability_analysis(
            self: "AssemblyCompoundStabilityAnalysis._Cast_AssemblyCompoundStabilityAnalysis",
        ) -> "_3897.AbstractAssemblyCompoundStabilityAnalysis":
            return self._parent._cast(_3897.AbstractAssemblyCompoundStabilityAnalysis)

        @property
        def part_compound_stability_analysis(
            self: "AssemblyCompoundStabilityAnalysis._Cast_AssemblyCompoundStabilityAnalysis",
        ) -> "_3976.PartCompoundStabilityAnalysis":
            from mastapy.system_model.analyses_and_results.stability_analyses.compound import (
                _3976,
            )

            return self._parent._cast(_3976.PartCompoundStabilityAnalysis)

        @property
        def part_compound_analysis(
            self: "AssemblyCompoundStabilityAnalysis._Cast_AssemblyCompoundStabilityAnalysis",
        ) -> "_7546.PartCompoundAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7546

            return self._parent._cast(_7546.PartCompoundAnalysis)

        @property
        def design_entity_compound_analysis(
            self: "AssemblyCompoundStabilityAnalysis._Cast_AssemblyCompoundStabilityAnalysis",
        ) -> "_7543.DesignEntityCompoundAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7543

            return self._parent._cast(_7543.DesignEntityCompoundAnalysis)

        @property
        def design_entity_analysis(
            self: "AssemblyCompoundStabilityAnalysis._Cast_AssemblyCompoundStabilityAnalysis",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def root_assembly_compound_stability_analysis(
            self: "AssemblyCompoundStabilityAnalysis._Cast_AssemblyCompoundStabilityAnalysis",
        ) -> "_3991.RootAssemblyCompoundStabilityAnalysis":
            from mastapy.system_model.analyses_and_results.stability_analyses.compound import (
                _3991,
            )

            return self._parent._cast(_3991.RootAssemblyCompoundStabilityAnalysis)

        @property
        def assembly_compound_stability_analysis(
            self: "AssemblyCompoundStabilityAnalysis._Cast_AssemblyCompoundStabilityAnalysis",
        ) -> "AssemblyCompoundStabilityAnalysis":
            return self._parent

        def __getattr__(
            self: "AssemblyCompoundStabilityAnalysis._Cast_AssemblyCompoundStabilityAnalysis",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self, instance_to_wrap: "AssemblyCompoundStabilityAnalysis.TYPE"
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self: Self) -> "_2433.Assembly":
        """mastapy.system_model.part_model.Assembly

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def assembly_design(self: Self) -> "_2433.Assembly":
        """mastapy.system_model.part_model.Assembly

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def assembly_analysis_cases_ready(
        self: Self,
    ) -> "List[_3770.AssemblyStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.AssemblyStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def bearings(self: Self) -> "List[_3905.BearingCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.BearingCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Bearings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def belt_drives(self: Self) -> "List[_3907.BeltDriveCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.BeltDriveCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BeltDrives

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def bevel_differential_gear_sets(
        self: Self,
    ) -> "List[_3910.BevelDifferentialGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.BevelDifferentialGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BevelDifferentialGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def bolted_joints(self: Self) -> "List[_3917.BoltedJointCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.BoltedJointCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BoltedJoints

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def bolts(self: Self) -> "List[_3916.BoltCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.BoltCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Bolts

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cv_ts(self: Self) -> "List[_3938.CVTCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.CVTCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CVTs

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def clutches(self: Self) -> "List[_3918.ClutchCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.ClutchCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Clutches

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def concept_couplings(
        self: Self,
    ) -> "List[_3923.ConceptCouplingCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.ConceptCouplingCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConceptCouplings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def concept_gear_sets(
        self: Self,
    ) -> "List[_3928.ConceptGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.ConceptGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConceptGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cycloidal_assemblies(
        self: Self,
    ) -> "List[_3940.CycloidalAssemblyCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.CycloidalAssemblyCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CycloidalAssemblies

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cycloidal_discs(
        self: Self,
    ) -> "List[_3942.CycloidalDiscCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.CycloidalDiscCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CycloidalDiscs

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cylindrical_gear_sets(
        self: Self,
    ) -> "List[_3946.CylindricalGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.CylindricalGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CylindricalGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def fe_parts(self: Self) -> "List[_3953.FEPartCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.FEPartCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FEParts

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def face_gear_sets(
        self: Self,
    ) -> "List[_3952.FaceGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.FaceGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FaceGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def flexible_pin_assemblies(
        self: Self,
    ) -> "List[_3954.FlexiblePinAssemblyCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.FlexiblePinAssemblyCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FlexiblePinAssemblies

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def hypoid_gear_sets(
        self: Self,
    ) -> "List[_3961.HypoidGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.HypoidGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HypoidGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_sets(
        self: Self,
    ) -> "List[_3968.KlingelnbergCycloPalloidHypoidGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.KlingelnbergCycloPalloidHypoidGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.KlingelnbergCycloPalloidHypoidGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_sets(
        self: Self,
    ) -> "List[_3971.KlingelnbergCycloPalloidSpiralBevelGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.KlingelnbergCycloPalloidSpiralBevelGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.KlingelnbergCycloPalloidSpiralBevelGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def mass_discs(self: Self) -> "List[_3972.MassDiscCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.MassDiscCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MassDiscs

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def measurement_components(
        self: Self,
    ) -> "List[_3973.MeasurementComponentCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.MeasurementComponentCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeasurementComponents

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def oil_seals(self: Self) -> "List[_3975.OilSealCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.OilSealCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OilSeals

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def part_to_part_shear_couplings(
        self: Self,
    ) -> "List[_3977.PartToPartShearCouplingCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.PartToPartShearCouplingCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PartToPartShearCouplings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def planet_carriers(
        self: Self,
    ) -> "List[_3982.PlanetCarrierCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.PlanetCarrierCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PlanetCarriers

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def point_loads(self: Self) -> "List[_3983.PointLoadCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.PointLoadCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PointLoads

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def power_loads(self: Self) -> "List[_3984.PowerLoadCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.PowerLoadCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PowerLoads

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def ring_pins(self: Self) -> "List[_3986.RingPinsCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.RingPinsCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RingPins

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def rolling_ring_assemblies(
        self: Self,
    ) -> "List[_3988.RollingRingAssemblyCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.RollingRingAssemblyCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RollingRingAssemblies

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def shaft_hub_connections(
        self: Self,
    ) -> "List[_3993.ShaftHubConnectionCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.ShaftHubConnectionCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShaftHubConnections

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def shafts(self: Self) -> "List[_3992.ShaftCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.ShaftCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Shafts

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def spiral_bevel_gear_sets(
        self: Self,
    ) -> "List[_3998.SpiralBevelGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.SpiralBevelGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SpiralBevelGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def spring_dampers(
        self: Self,
    ) -> "List[_3999.SpringDamperCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.SpringDamperCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SpringDampers

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def straight_bevel_diff_gear_sets(
        self: Self,
    ) -> "List[_4004.StraightBevelDiffGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.StraightBevelDiffGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StraightBevelDiffGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def straight_bevel_gear_sets(
        self: Self,
    ) -> "List[_4007.StraightBevelGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.StraightBevelGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StraightBevelGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def synchronisers(
        self: Self,
    ) -> "List[_4010.SynchroniserCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.SynchroniserCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Synchronisers

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def torque_converters(
        self: Self,
    ) -> "List[_4014.TorqueConverterCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.TorqueConverterCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TorqueConverters

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def unbalanced_masses(
        self: Self,
    ) -> "List[_4018.UnbalancedMassCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.UnbalancedMassCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.UnbalancedMasses

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def worm_gear_sets(
        self: Self,
    ) -> "List[_4022.WormGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.WormGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WormGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def zerol_bevel_gear_sets(
        self: Self,
    ) -> "List[_4025.ZerolBevelGearSetCompoundStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.compound.ZerolBevelGearSetCompoundStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ZerolBevelGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def assembly_analysis_cases(self: Self) -> "List[_3770.AssemblyStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.AssemblyStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: Self,
    ) -> "AssemblyCompoundStabilityAnalysis._Cast_AssemblyCompoundStabilityAnalysis":
        return self._Cast_AssemblyCompoundStabilityAnalysis(self)



"""CylindricalGearTableMGItemDetail"""
from __future__ import annotations

from typing import TypeVar, Any
from enum import Enum

from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_TABLE_MG_ITEM_DETAIL = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Cylindrical", "CylindricalGearTableMGItemDetail"
)


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearTableMGItemDetail",)


Self = TypeVar("Self", bound="CylindricalGearTableMGItemDetail")


class CylindricalGearTableMGItemDetail(Enum):
    """CylindricalGearTableMGItemDetail

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls):
        return _CYLINDRICAL_GEAR_TABLE_MG_ITEM_DETAIL

    CHART = 0
    REPORT = 1
    REPORT_AND_CHART = 2


def __enum_setattr(self: Self, attr: str, value: Any):
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: Self, attr: str):
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


CylindricalGearTableMGItemDetail.__setattr__ = __enum_setattr
CylindricalGearTableMGItemDetail.__delattr__ = __enum_delattr



"""KeyedJointDesign"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, Union, Tuple

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor, conversion
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy.detailed_rigid_connectors.interference_fits import _1444
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_KEYED_JOINT_DESIGN = python_net_import(
    "SMT.MastaAPI.DetailedRigidConnectors.KeyedJoints", "KeyedJointDesign"
)

if TYPE_CHECKING:
    from mastapy.detailed_rigid_connectors.keyed_joints import _1437, _1439
    from mastapy.detailed_rigid_connectors import _1386


__docformat__ = "restructuredtext en"
__all__ = ("KeyedJointDesign",)


Self = TypeVar("Self", bound="KeyedJointDesign")


class KeyedJointDesign(_1444.InterferenceFitDesign):
    """KeyedJointDesign

    This is a mastapy class.
    """

    TYPE = _KEYED_JOINT_DESIGN
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_KeyedJointDesign")

    class _Cast_KeyedJointDesign:
        """Special nested class for casting KeyedJointDesign to subclasses."""

        def __init__(
            self: "KeyedJointDesign._Cast_KeyedJointDesign", parent: "KeyedJointDesign"
        ):
            self._parent = parent

        @property
        def interference_fit_design(
            self: "KeyedJointDesign._Cast_KeyedJointDesign",
        ) -> "_1444.InterferenceFitDesign":
            return self._parent._cast(_1444.InterferenceFitDesign)

        @property
        def detailed_rigid_connector_design(
            self: "KeyedJointDesign._Cast_KeyedJointDesign",
        ) -> "_1386.DetailedRigidConnectorDesign":
            from mastapy.detailed_rigid_connectors import _1386

            return self._parent._cast(_1386.DetailedRigidConnectorDesign)

        @property
        def keyed_joint_design(
            self: "KeyedJointDesign._Cast_KeyedJointDesign",
        ) -> "KeyedJointDesign":
            return self._parent

        def __getattr__(self: "KeyedJointDesign._Cast_KeyedJointDesign", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "KeyedJointDesign.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def allowable_contact_stress_for_inner_component(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AllowableContactStressForInnerComponent

        if temp is None:
            return 0.0

        return temp

    @property
    def allowable_contact_stress_for_key(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AllowableContactStressForKey

        if temp is None:
            return 0.0

        return temp

    @property
    def allowable_contact_stress_for_outer_component(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AllowableContactStressForOuterComponent

        if temp is None:
            return 0.0

        return temp

    @property
    def edge_chamfer(self: Self) -> "float":
        """float"""
        temp = self.wrapped.EdgeChamfer

        if temp is None:
            return 0.0

        return temp

    @edge_chamfer.setter
    @enforce_parameter_types
    def edge_chamfer(self: Self, value: "float"):
        self.wrapped.EdgeChamfer = float(value) if value is not None else 0.0

    @property
    def geometry_type(self: Self) -> "_1437.KeyTypes":
        """mastapy.detailed_rigid_connectors.keyed_joints.KeyTypes"""
        temp = self.wrapped.GeometryType

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.DetailedRigidConnectors.KeyedJoints.KeyTypes"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.detailed_rigid_connectors.keyed_joints._1437", "KeyTypes"
        )(value)

    @geometry_type.setter
    @enforce_parameter_types
    def geometry_type(self: Self, value: "_1437.KeyTypes"):
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.DetailedRigidConnectors.KeyedJoints.KeyTypes"
        )
        self.wrapped.GeometryType = value

    @property
    def height(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Height

        if temp is None:
            return 0.0

        return temp

    @height.setter
    @enforce_parameter_types
    def height(self: Self, value: "float"):
        self.wrapped.Height = float(value) if value is not None else 0.0

    @property
    def inclined_underside_chamfer(self: Self) -> "float":
        """float"""
        temp = self.wrapped.InclinedUndersideChamfer

        if temp is None:
            return 0.0

        return temp

    @inclined_underside_chamfer.setter
    @enforce_parameter_types
    def inclined_underside_chamfer(self: Self, value: "float"):
        self.wrapped.InclinedUndersideChamfer = (
            float(value) if value is not None else 0.0
        )

    @property
    def interference_fit_length(self: Self) -> "float":
        """float"""
        temp = self.wrapped.InterferenceFitLength

        if temp is None:
            return 0.0

        return temp

    @interference_fit_length.setter
    @enforce_parameter_types
    def interference_fit_length(self: Self, value: "float"):
        self.wrapped.InterferenceFitLength = float(value) if value is not None else 0.0

    @property
    def is_interference_fit(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.IsInterferenceFit

        if temp is None:
            return False

        return temp

    @is_interference_fit.setter
    @enforce_parameter_types
    def is_interference_fit(self: Self, value: "bool"):
        self.wrapped.IsInterferenceFit = bool(value) if value is not None else False

    @property
    def is_key_case_hardened(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.IsKeyCaseHardened

        if temp is None:
            return False

        return temp

    @is_key_case_hardened.setter
    @enforce_parameter_types
    def is_key_case_hardened(self: Self, value: "bool"):
        self.wrapped.IsKeyCaseHardened = bool(value) if value is not None else False

    @property
    def key_effective_length(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.KeyEffectiveLength

        if temp is None:
            return 0.0

        return temp

    @property
    def keyway_depth_inner_component(self: Self) -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.KeywayDepthInnerComponent

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @keyway_depth_inner_component.setter
    @enforce_parameter_types
    def keyway_depth_inner_component(
        self: Self, value: "Union[float, Tuple[float, bool]]"
    ):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.KeywayDepthInnerComponent = value

    @property
    def keyway_depth_outer_component(self: Self) -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.KeywayDepthOuterComponent

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @keyway_depth_outer_component.setter
    @enforce_parameter_types
    def keyway_depth_outer_component(
        self: Self, value: "Union[float, Tuple[float, bool]]"
    ):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.KeywayDepthOuterComponent = value

    @property
    def length(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Length

        if temp is None:
            return 0.0

        return temp

    @length.setter
    @enforce_parameter_types
    def length(self: Self, value: "float"):
        self.wrapped.Length = float(value) if value is not None else 0.0

    @property
    def number_of_keys(self: Self) -> "_1439.NumberOfKeys":
        """mastapy.detailed_rigid_connectors.keyed_joints.NumberOfKeys"""
        temp = self.wrapped.NumberOfKeys

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.DetailedRigidConnectors.KeyedJoints.NumberOfKeys"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.detailed_rigid_connectors.keyed_joints._1439", "NumberOfKeys"
        )(value)

    @number_of_keys.setter
    @enforce_parameter_types
    def number_of_keys(self: Self, value: "_1439.NumberOfKeys"):
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.DetailedRigidConnectors.KeyedJoints.NumberOfKeys"
        )
        self.wrapped.NumberOfKeys = value

    @property
    def position_offset(self: Self) -> "float":
        """float"""
        temp = self.wrapped.PositionOffset

        if temp is None:
            return 0.0

        return temp

    @position_offset.setter
    @enforce_parameter_types
    def position_offset(self: Self, value: "float"):
        self.wrapped.PositionOffset = float(value) if value is not None else 0.0

    @property
    def tensile_yield_strength(self: Self) -> "float":
        """float"""
        temp = self.wrapped.TensileYieldStrength

        if temp is None:
            return 0.0

        return temp

    @tensile_yield_strength.setter
    @enforce_parameter_types
    def tensile_yield_strength(self: Self, value: "float"):
        self.wrapped.TensileYieldStrength = float(value) if value is not None else 0.0

    @property
    def width(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Width

        if temp is None:
            return 0.0

        return temp

    @width.setter
    @enforce_parameter_types
    def width(self: Self, value: "float"):
        self.wrapped.Width = float(value) if value is not None else 0.0

    @property
    def cast_to(self: Self) -> "KeyedJointDesign._Cast_KeyedJointDesign":
        return self._Cast_KeyedJointDesign(self)



"""StraightBevelGearMeshPowerFlow"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.power_flows import _4048
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_GEAR_MESH_POWER_FLOW = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.PowerFlows",
    "StraightBevelGearMeshPowerFlow",
)

if TYPE_CHECKING:
    from mastapy.gears.rating.straight_bevel import _395
    from mastapy.system_model.connections_and_sockets.gears import _2327
    from mastapy.system_model.analyses_and_results.static_loads import _6964
    from mastapy.system_model.analyses_and_results.power_flows import (
        _4036,
        _4064,
        _4093,
        _4100,
        _4067,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import _7541, _7538
    from mastapy.system_model.analyses_and_results import _2649, _2653, _2651


__docformat__ = "restructuredtext en"
__all__ = ("StraightBevelGearMeshPowerFlow",)


Self = TypeVar("Self", bound="StraightBevelGearMeshPowerFlow")


class StraightBevelGearMeshPowerFlow(_4048.BevelGearMeshPowerFlow):
    """StraightBevelGearMeshPowerFlow

    This is a mastapy class.
    """

    TYPE = _STRAIGHT_BEVEL_GEAR_MESH_POWER_FLOW
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_StraightBevelGearMeshPowerFlow")

    class _Cast_StraightBevelGearMeshPowerFlow:
        """Special nested class for casting StraightBevelGearMeshPowerFlow to subclasses."""

        def __init__(
            self: "StraightBevelGearMeshPowerFlow._Cast_StraightBevelGearMeshPowerFlow",
            parent: "StraightBevelGearMeshPowerFlow",
        ):
            self._parent = parent

        @property
        def bevel_gear_mesh_power_flow(
            self: "StraightBevelGearMeshPowerFlow._Cast_StraightBevelGearMeshPowerFlow",
        ) -> "_4048.BevelGearMeshPowerFlow":
            return self._parent._cast(_4048.BevelGearMeshPowerFlow)

        @property
        def agma_gleason_conical_gear_mesh_power_flow(
            self: "StraightBevelGearMeshPowerFlow._Cast_StraightBevelGearMeshPowerFlow",
        ) -> "_4036.AGMAGleasonConicalGearMeshPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows import _4036

            return self._parent._cast(_4036.AGMAGleasonConicalGearMeshPowerFlow)

        @property
        def conical_gear_mesh_power_flow(
            self: "StraightBevelGearMeshPowerFlow._Cast_StraightBevelGearMeshPowerFlow",
        ) -> "_4064.ConicalGearMeshPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows import _4064

            return self._parent._cast(_4064.ConicalGearMeshPowerFlow)

        @property
        def gear_mesh_power_flow(
            self: "StraightBevelGearMeshPowerFlow._Cast_StraightBevelGearMeshPowerFlow",
        ) -> "_4093.GearMeshPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows import _4093

            return self._parent._cast(_4093.GearMeshPowerFlow)

        @property
        def inter_mountable_component_connection_power_flow(
            self: "StraightBevelGearMeshPowerFlow._Cast_StraightBevelGearMeshPowerFlow",
        ) -> "_4100.InterMountableComponentConnectionPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows import _4100

            return self._parent._cast(_4100.InterMountableComponentConnectionPowerFlow)

        @property
        def connection_power_flow(
            self: "StraightBevelGearMeshPowerFlow._Cast_StraightBevelGearMeshPowerFlow",
        ) -> "_4067.ConnectionPowerFlow":
            from mastapy.system_model.analyses_and_results.power_flows import _4067

            return self._parent._cast(_4067.ConnectionPowerFlow)

        @property
        def connection_static_load_analysis_case(
            self: "StraightBevelGearMeshPowerFlow._Cast_StraightBevelGearMeshPowerFlow",
        ) -> "_7541.ConnectionStaticLoadAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7541

            return self._parent._cast(_7541.ConnectionStaticLoadAnalysisCase)

        @property
        def connection_analysis_case(
            self: "StraightBevelGearMeshPowerFlow._Cast_StraightBevelGearMeshPowerFlow",
        ) -> "_7538.ConnectionAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7538

            return self._parent._cast(_7538.ConnectionAnalysisCase)

        @property
        def connection_analysis(
            self: "StraightBevelGearMeshPowerFlow._Cast_StraightBevelGearMeshPowerFlow",
        ) -> "_2649.ConnectionAnalysis":
            from mastapy.system_model.analyses_and_results import _2649

            return self._parent._cast(_2649.ConnectionAnalysis)

        @property
        def design_entity_single_context_analysis(
            self: "StraightBevelGearMeshPowerFlow._Cast_StraightBevelGearMeshPowerFlow",
        ) -> "_2653.DesignEntitySingleContextAnalysis":
            from mastapy.system_model.analyses_and_results import _2653

            return self._parent._cast(_2653.DesignEntitySingleContextAnalysis)

        @property
        def design_entity_analysis(
            self: "StraightBevelGearMeshPowerFlow._Cast_StraightBevelGearMeshPowerFlow",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def straight_bevel_gear_mesh_power_flow(
            self: "StraightBevelGearMeshPowerFlow._Cast_StraightBevelGearMeshPowerFlow",
        ) -> "StraightBevelGearMeshPowerFlow":
            return self._parent

        def __getattr__(
            self: "StraightBevelGearMeshPowerFlow._Cast_StraightBevelGearMeshPowerFlow",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "StraightBevelGearMeshPowerFlow.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def rating(self: Self) -> "_395.StraightBevelGearMeshRating":
        """mastapy.gears.rating.straight_bevel.StraightBevelGearMeshRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Rating

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def component_detailed_analysis(self: Self) -> "_395.StraightBevelGearMeshRating":
        """mastapy.gears.rating.straight_bevel.StraightBevelGearMeshRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDetailedAnalysis

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def connection_design(self: Self) -> "_2327.StraightBevelGearMesh":
        """mastapy.system_model.connections_and_sockets.gears.StraightBevelGearMesh

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def connection_load_case(self: Self) -> "_6964.StraightBevelGearMeshLoadCase":
        """mastapy.system_model.analyses_and_results.static_loads.StraightBevelGearMeshLoadCase

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionLoadCase

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "StraightBevelGearMeshPowerFlow._Cast_StraightBevelGearMeshPowerFlow":
        return self._Cast_StraightBevelGearMeshPowerFlow(self)



"""__init__.py"""

import sys
from typing import TYPE_CHECKING

from lazy_imports import LazyImporter


if TYPE_CHECKING:
    from ._6277 import AbstractAssemblyDynamicAnalysis
    from ._6278 import AbstractShaftDynamicAnalysis
    from ._6279 import AbstractShaftOrHousingDynamicAnalysis
    from ._6280 import AbstractShaftToMountableComponentConnectionDynamicAnalysis
    from ._6281 import AGMAGleasonConicalGearDynamicAnalysis
    from ._6282 import AGMAGleasonConicalGearMeshDynamicAnalysis
    from ._6283 import AGMAGleasonConicalGearSetDynamicAnalysis
    from ._6284 import AssemblyDynamicAnalysis
    from ._6285 import BearingDynamicAnalysis
    from ._6286 import BeltConnectionDynamicAnalysis
    from ._6287 import BeltDriveDynamicAnalysis
    from ._6288 import BevelDifferentialGearDynamicAnalysis
    from ._6289 import BevelDifferentialGearMeshDynamicAnalysis
    from ._6290 import BevelDifferentialGearSetDynamicAnalysis
    from ._6291 import BevelDifferentialPlanetGearDynamicAnalysis
    from ._6292 import BevelDifferentialSunGearDynamicAnalysis
    from ._6293 import BevelGearDynamicAnalysis
    from ._6294 import BevelGearMeshDynamicAnalysis
    from ._6295 import BevelGearSetDynamicAnalysis
    from ._6296 import BoltDynamicAnalysis
    from ._6297 import BoltedJointDynamicAnalysis
    from ._6298 import ClutchConnectionDynamicAnalysis
    from ._6299 import ClutchDynamicAnalysis
    from ._6300 import ClutchHalfDynamicAnalysis
    from ._6301 import CoaxialConnectionDynamicAnalysis
    from ._6302 import ComponentDynamicAnalysis
    from ._6303 import ConceptCouplingConnectionDynamicAnalysis
    from ._6304 import ConceptCouplingDynamicAnalysis
    from ._6305 import ConceptCouplingHalfDynamicAnalysis
    from ._6306 import ConceptGearDynamicAnalysis
    from ._6307 import ConceptGearMeshDynamicAnalysis
    from ._6308 import ConceptGearSetDynamicAnalysis
    from ._6309 import ConicalGearDynamicAnalysis
    from ._6310 import ConicalGearMeshDynamicAnalysis
    from ._6311 import ConicalGearSetDynamicAnalysis
    from ._6312 import ConnectionDynamicAnalysis
    from ._6313 import ConnectorDynamicAnalysis
    from ._6314 import CouplingConnectionDynamicAnalysis
    from ._6315 import CouplingDynamicAnalysis
    from ._6316 import CouplingHalfDynamicAnalysis
    from ._6317 import CVTBeltConnectionDynamicAnalysis
    from ._6318 import CVTDynamicAnalysis
    from ._6319 import CVTPulleyDynamicAnalysis
    from ._6320 import CycloidalAssemblyDynamicAnalysis
    from ._6321 import CycloidalDiscCentralBearingConnectionDynamicAnalysis
    from ._6322 import CycloidalDiscDynamicAnalysis
    from ._6323 import CycloidalDiscPlanetaryBearingConnectionDynamicAnalysis
    from ._6324 import CylindricalGearDynamicAnalysis
    from ._6325 import CylindricalGearMeshDynamicAnalysis
    from ._6326 import CylindricalGearSetDynamicAnalysis
    from ._6327 import CylindricalPlanetGearDynamicAnalysis
    from ._6328 import DatumDynamicAnalysis
    from ._6329 import DynamicAnalysis
    from ._6330 import DynamicAnalysisDrawStyle
    from ._6331 import ExternalCADModelDynamicAnalysis
    from ._6332 import FaceGearDynamicAnalysis
    from ._6333 import FaceGearMeshDynamicAnalysis
    from ._6334 import FaceGearSetDynamicAnalysis
    from ._6335 import FEPartDynamicAnalysis
    from ._6336 import FlexiblePinAssemblyDynamicAnalysis
    from ._6337 import GearDynamicAnalysis
    from ._6338 import GearMeshDynamicAnalysis
    from ._6339 import GearSetDynamicAnalysis
    from ._6340 import GuideDxfModelDynamicAnalysis
    from ._6341 import HypoidGearDynamicAnalysis
    from ._6342 import HypoidGearMeshDynamicAnalysis
    from ._6343 import HypoidGearSetDynamicAnalysis
    from ._6344 import InterMountableComponentConnectionDynamicAnalysis
    from ._6345 import KlingelnbergCycloPalloidConicalGearDynamicAnalysis
    from ._6346 import KlingelnbergCycloPalloidConicalGearMeshDynamicAnalysis
    from ._6347 import KlingelnbergCycloPalloidConicalGearSetDynamicAnalysis
    from ._6348 import KlingelnbergCycloPalloidHypoidGearDynamicAnalysis
    from ._6349 import KlingelnbergCycloPalloidHypoidGearMeshDynamicAnalysis
    from ._6350 import KlingelnbergCycloPalloidHypoidGearSetDynamicAnalysis
    from ._6351 import KlingelnbergCycloPalloidSpiralBevelGearDynamicAnalysis
    from ._6352 import KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis
    from ._6353 import KlingelnbergCycloPalloidSpiralBevelGearSetDynamicAnalysis
    from ._6354 import MassDiscDynamicAnalysis
    from ._6355 import MeasurementComponentDynamicAnalysis
    from ._6356 import MountableComponentDynamicAnalysis
    from ._6357 import OilSealDynamicAnalysis
    from ._6358 import PartDynamicAnalysis
    from ._6359 import PartToPartShearCouplingConnectionDynamicAnalysis
    from ._6360 import PartToPartShearCouplingDynamicAnalysis
    from ._6361 import PartToPartShearCouplingHalfDynamicAnalysis
    from ._6362 import PlanetaryConnectionDynamicAnalysis
    from ._6363 import PlanetaryGearSetDynamicAnalysis
    from ._6364 import PlanetCarrierDynamicAnalysis
    from ._6365 import PointLoadDynamicAnalysis
    from ._6366 import PowerLoadDynamicAnalysis
    from ._6367 import PulleyDynamicAnalysis
    from ._6368 import RingPinsDynamicAnalysis
    from ._6369 import RingPinsToDiscConnectionDynamicAnalysis
    from ._6370 import RollingRingAssemblyDynamicAnalysis
    from ._6371 import RollingRingConnectionDynamicAnalysis
    from ._6372 import RollingRingDynamicAnalysis
    from ._6373 import RootAssemblyDynamicAnalysis
    from ._6374 import ShaftDynamicAnalysis
    from ._6375 import ShaftHubConnectionDynamicAnalysis
    from ._6376 import ShaftToMountableComponentConnectionDynamicAnalysis
    from ._6377 import SpecialisedAssemblyDynamicAnalysis
    from ._6378 import SpiralBevelGearDynamicAnalysis
    from ._6379 import SpiralBevelGearMeshDynamicAnalysis
    from ._6380 import SpiralBevelGearSetDynamicAnalysis
    from ._6381 import SpringDamperConnectionDynamicAnalysis
    from ._6382 import SpringDamperDynamicAnalysis
    from ._6383 import SpringDamperHalfDynamicAnalysis
    from ._6384 import StraightBevelDiffGearDynamicAnalysis
    from ._6385 import StraightBevelDiffGearMeshDynamicAnalysis
    from ._6386 import StraightBevelDiffGearSetDynamicAnalysis
    from ._6387 import StraightBevelGearDynamicAnalysis
    from ._6388 import StraightBevelGearMeshDynamicAnalysis
    from ._6389 import StraightBevelGearSetDynamicAnalysis
    from ._6390 import StraightBevelPlanetGearDynamicAnalysis
    from ._6391 import StraightBevelSunGearDynamicAnalysis
    from ._6392 import SynchroniserDynamicAnalysis
    from ._6393 import SynchroniserHalfDynamicAnalysis
    from ._6394 import SynchroniserPartDynamicAnalysis
    from ._6395 import SynchroniserSleeveDynamicAnalysis
    from ._6396 import TorqueConverterConnectionDynamicAnalysis
    from ._6397 import TorqueConverterDynamicAnalysis
    from ._6398 import TorqueConverterPumpDynamicAnalysis
    from ._6399 import TorqueConverterTurbineDynamicAnalysis
    from ._6400 import UnbalancedMassDynamicAnalysis
    from ._6401 import VirtualComponentDynamicAnalysis
    from ._6402 import WormGearDynamicAnalysis
    from ._6403 import WormGearMeshDynamicAnalysis
    from ._6404 import WormGearSetDynamicAnalysis
    from ._6405 import ZerolBevelGearDynamicAnalysis
    from ._6406 import ZerolBevelGearMeshDynamicAnalysis
    from ._6407 import ZerolBevelGearSetDynamicAnalysis
else:
    import_structure = {
        "_6277": ["AbstractAssemblyDynamicAnalysis"],
        "_6278": ["AbstractShaftDynamicAnalysis"],
        "_6279": ["AbstractShaftOrHousingDynamicAnalysis"],
        "_6280": ["AbstractShaftToMountableComponentConnectionDynamicAnalysis"],
        "_6281": ["AGMAGleasonConicalGearDynamicAnalysis"],
        "_6282": ["AGMAGleasonConicalGearMeshDynamicAnalysis"],
        "_6283": ["AGMAGleasonConicalGearSetDynamicAnalysis"],
        "_6284": ["AssemblyDynamicAnalysis"],
        "_6285": ["BearingDynamicAnalysis"],
        "_6286": ["BeltConnectionDynamicAnalysis"],
        "_6287": ["BeltDriveDynamicAnalysis"],
        "_6288": ["BevelDifferentialGearDynamicAnalysis"],
        "_6289": ["BevelDifferentialGearMeshDynamicAnalysis"],
        "_6290": ["BevelDifferentialGearSetDynamicAnalysis"],
        "_6291": ["BevelDifferentialPlanetGearDynamicAnalysis"],
        "_6292": ["BevelDifferentialSunGearDynamicAnalysis"],
        "_6293": ["BevelGearDynamicAnalysis"],
        "_6294": ["BevelGearMeshDynamicAnalysis"],
        "_6295": ["BevelGearSetDynamicAnalysis"],
        "_6296": ["BoltDynamicAnalysis"],
        "_6297": ["BoltedJointDynamicAnalysis"],
        "_6298": ["ClutchConnectionDynamicAnalysis"],
        "_6299": ["ClutchDynamicAnalysis"],
        "_6300": ["ClutchHalfDynamicAnalysis"],
        "_6301": ["CoaxialConnectionDynamicAnalysis"],
        "_6302": ["ComponentDynamicAnalysis"],
        "_6303": ["ConceptCouplingConnectionDynamicAnalysis"],
        "_6304": ["ConceptCouplingDynamicAnalysis"],
        "_6305": ["ConceptCouplingHalfDynamicAnalysis"],
        "_6306": ["ConceptGearDynamicAnalysis"],
        "_6307": ["ConceptGearMeshDynamicAnalysis"],
        "_6308": ["ConceptGearSetDynamicAnalysis"],
        "_6309": ["ConicalGearDynamicAnalysis"],
        "_6310": ["ConicalGearMeshDynamicAnalysis"],
        "_6311": ["ConicalGearSetDynamicAnalysis"],
        "_6312": ["ConnectionDynamicAnalysis"],
        "_6313": ["ConnectorDynamicAnalysis"],
        "_6314": ["CouplingConnectionDynamicAnalysis"],
        "_6315": ["CouplingDynamicAnalysis"],
        "_6316": ["CouplingHalfDynamicAnalysis"],
        "_6317": ["CVTBeltConnectionDynamicAnalysis"],
        "_6318": ["CVTDynamicAnalysis"],
        "_6319": ["CVTPulleyDynamicAnalysis"],
        "_6320": ["CycloidalAssemblyDynamicAnalysis"],
        "_6321": ["CycloidalDiscCentralBearingConnectionDynamicAnalysis"],
        "_6322": ["CycloidalDiscDynamicAnalysis"],
        "_6323": ["CycloidalDiscPlanetaryBearingConnectionDynamicAnalysis"],
        "_6324": ["CylindricalGearDynamicAnalysis"],
        "_6325": ["CylindricalGearMeshDynamicAnalysis"],
        "_6326": ["CylindricalGearSetDynamicAnalysis"],
        "_6327": ["CylindricalPlanetGearDynamicAnalysis"],
        "_6328": ["DatumDynamicAnalysis"],
        "_6329": ["DynamicAnalysis"],
        "_6330": ["DynamicAnalysisDrawStyle"],
        "_6331": ["ExternalCADModelDynamicAnalysis"],
        "_6332": ["FaceGearDynamicAnalysis"],
        "_6333": ["FaceGearMeshDynamicAnalysis"],
        "_6334": ["FaceGearSetDynamicAnalysis"],
        "_6335": ["FEPartDynamicAnalysis"],
        "_6336": ["FlexiblePinAssemblyDynamicAnalysis"],
        "_6337": ["GearDynamicAnalysis"],
        "_6338": ["GearMeshDynamicAnalysis"],
        "_6339": ["GearSetDynamicAnalysis"],
        "_6340": ["GuideDxfModelDynamicAnalysis"],
        "_6341": ["HypoidGearDynamicAnalysis"],
        "_6342": ["HypoidGearMeshDynamicAnalysis"],
        "_6343": ["HypoidGearSetDynamicAnalysis"],
        "_6344": ["InterMountableComponentConnectionDynamicAnalysis"],
        "_6345": ["KlingelnbergCycloPalloidConicalGearDynamicAnalysis"],
        "_6346": ["KlingelnbergCycloPalloidConicalGearMeshDynamicAnalysis"],
        "_6347": ["KlingelnbergCycloPalloidConicalGearSetDynamicAnalysis"],
        "_6348": ["KlingelnbergCycloPalloidHypoidGearDynamicAnalysis"],
        "_6349": ["KlingelnbergCycloPalloidHypoidGearMeshDynamicAnalysis"],
        "_6350": ["KlingelnbergCycloPalloidHypoidGearSetDynamicAnalysis"],
        "_6351": ["KlingelnbergCycloPalloidSpiralBevelGearDynamicAnalysis"],
        "_6352": ["KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis"],
        "_6353": ["KlingelnbergCycloPalloidSpiralBevelGearSetDynamicAnalysis"],
        "_6354": ["MassDiscDynamicAnalysis"],
        "_6355": ["MeasurementComponentDynamicAnalysis"],
        "_6356": ["MountableComponentDynamicAnalysis"],
        "_6357": ["OilSealDynamicAnalysis"],
        "_6358": ["PartDynamicAnalysis"],
        "_6359": ["PartToPartShearCouplingConnectionDynamicAnalysis"],
        "_6360": ["PartToPartShearCouplingDynamicAnalysis"],
        "_6361": ["PartToPartShearCouplingHalfDynamicAnalysis"],
        "_6362": ["PlanetaryConnectionDynamicAnalysis"],
        "_6363": ["PlanetaryGearSetDynamicAnalysis"],
        "_6364": ["PlanetCarrierDynamicAnalysis"],
        "_6365": ["PointLoadDynamicAnalysis"],
        "_6366": ["PowerLoadDynamicAnalysis"],
        "_6367": ["PulleyDynamicAnalysis"],
        "_6368": ["RingPinsDynamicAnalysis"],
        "_6369": ["RingPinsToDiscConnectionDynamicAnalysis"],
        "_6370": ["RollingRingAssemblyDynamicAnalysis"],
        "_6371": ["RollingRingConnectionDynamicAnalysis"],
        "_6372": ["RollingRingDynamicAnalysis"],
        "_6373": ["RootAssemblyDynamicAnalysis"],
        "_6374": ["ShaftDynamicAnalysis"],
        "_6375": ["ShaftHubConnectionDynamicAnalysis"],
        "_6376": ["ShaftToMountableComponentConnectionDynamicAnalysis"],
        "_6377": ["SpecialisedAssemblyDynamicAnalysis"],
        "_6378": ["SpiralBevelGearDynamicAnalysis"],
        "_6379": ["SpiralBevelGearMeshDynamicAnalysis"],
        "_6380": ["SpiralBevelGearSetDynamicAnalysis"],
        "_6381": ["SpringDamperConnectionDynamicAnalysis"],
        "_6382": ["SpringDamperDynamicAnalysis"],
        "_6383": ["SpringDamperHalfDynamicAnalysis"],
        "_6384": ["StraightBevelDiffGearDynamicAnalysis"],
        "_6385": ["StraightBevelDiffGearMeshDynamicAnalysis"],
        "_6386": ["StraightBevelDiffGearSetDynamicAnalysis"],
        "_6387": ["StraightBevelGearDynamicAnalysis"],
        "_6388": ["StraightBevelGearMeshDynamicAnalysis"],
        "_6389": ["StraightBevelGearSetDynamicAnalysis"],
        "_6390": ["StraightBevelPlanetGearDynamicAnalysis"],
        "_6391": ["StraightBevelSunGearDynamicAnalysis"],
        "_6392": ["SynchroniserDynamicAnalysis"],
        "_6393": ["SynchroniserHalfDynamicAnalysis"],
        "_6394": ["SynchroniserPartDynamicAnalysis"],
        "_6395": ["SynchroniserSleeveDynamicAnalysis"],
        "_6396": ["TorqueConverterConnectionDynamicAnalysis"],
        "_6397": ["TorqueConverterDynamicAnalysis"],
        "_6398": ["TorqueConverterPumpDynamicAnalysis"],
        "_6399": ["TorqueConverterTurbineDynamicAnalysis"],
        "_6400": ["UnbalancedMassDynamicAnalysis"],
        "_6401": ["VirtualComponentDynamicAnalysis"],
        "_6402": ["WormGearDynamicAnalysis"],
        "_6403": ["WormGearMeshDynamicAnalysis"],
        "_6404": ["WormGearSetDynamicAnalysis"],
        "_6405": ["ZerolBevelGearDynamicAnalysis"],
        "_6406": ["ZerolBevelGearMeshDynamicAnalysis"],
        "_6407": ["ZerolBevelGearSetDynamicAnalysis"],
    }

    sys.modules[__name__] = LazyImporter(
        __name__,
        globals()["__file__"],
        import_structure,
    )

__all__ = (
    "AbstractAssemblyDynamicAnalysis",
    "AbstractShaftDynamicAnalysis",
    "AbstractShaftOrHousingDynamicAnalysis",
    "AbstractShaftToMountableComponentConnectionDynamicAnalysis",
    "AGMAGleasonConicalGearDynamicAnalysis",
    "AGMAGleasonConicalGearMeshDynamicAnalysis",
    "AGMAGleasonConicalGearSetDynamicAnalysis",
    "AssemblyDynamicAnalysis",
    "BearingDynamicAnalysis",
    "BeltConnectionDynamicAnalysis",
    "BeltDriveDynamicAnalysis",
    "BevelDifferentialGearDynamicAnalysis",
    "BevelDifferentialGearMeshDynamicAnalysis",
    "BevelDifferentialGearSetDynamicAnalysis",
    "BevelDifferentialPlanetGearDynamicAnalysis",
    "BevelDifferentialSunGearDynamicAnalysis",
    "BevelGearDynamicAnalysis",
    "BevelGearMeshDynamicAnalysis",
    "BevelGearSetDynamicAnalysis",
    "BoltDynamicAnalysis",
    "BoltedJointDynamicAnalysis",
    "ClutchConnectionDynamicAnalysis",
    "ClutchDynamicAnalysis",
    "ClutchHalfDynamicAnalysis",
    "CoaxialConnectionDynamicAnalysis",
    "ComponentDynamicAnalysis",
    "ConceptCouplingConnectionDynamicAnalysis",
    "ConceptCouplingDynamicAnalysis",
    "ConceptCouplingHalfDynamicAnalysis",
    "ConceptGearDynamicAnalysis",
    "ConceptGearMeshDynamicAnalysis",
    "ConceptGearSetDynamicAnalysis",
    "ConicalGearDynamicAnalysis",
    "ConicalGearMeshDynamicAnalysis",
    "ConicalGearSetDynamicAnalysis",
    "ConnectionDynamicAnalysis",
    "ConnectorDynamicAnalysis",
    "CouplingConnectionDynamicAnalysis",
    "CouplingDynamicAnalysis",
    "CouplingHalfDynamicAnalysis",
    "CVTBeltConnectionDynamicAnalysis",
    "CVTDynamicAnalysis",
    "CVTPulleyDynamicAnalysis",
    "CycloidalAssemblyDynamicAnalysis",
    "CycloidalDiscCentralBearingConnectionDynamicAnalysis",
    "CycloidalDiscDynamicAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionDynamicAnalysis",
    "CylindricalGearDynamicAnalysis",
    "CylindricalGearMeshDynamicAnalysis",
    "CylindricalGearSetDynamicAnalysis",
    "CylindricalPlanetGearDynamicAnalysis",
    "DatumDynamicAnalysis",
    "DynamicAnalysis",
    "DynamicAnalysisDrawStyle",
    "ExternalCADModelDynamicAnalysis",
    "FaceGearDynamicAnalysis",
    "FaceGearMeshDynamicAnalysis",
    "FaceGearSetDynamicAnalysis",
    "FEPartDynamicAnalysis",
    "FlexiblePinAssemblyDynamicAnalysis",
    "GearDynamicAnalysis",
    "GearMeshDynamicAnalysis",
    "GearSetDynamicAnalysis",
    "GuideDxfModelDynamicAnalysis",
    "HypoidGearDynamicAnalysis",
    "HypoidGearMeshDynamicAnalysis",
    "HypoidGearSetDynamicAnalysis",
    "InterMountableComponentConnectionDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetDynamicAnalysis",
    "MassDiscDynamicAnalysis",
    "MeasurementComponentDynamicAnalysis",
    "MountableComponentDynamicAnalysis",
    "OilSealDynamicAnalysis",
    "PartDynamicAnalysis",
    "PartToPartShearCouplingConnectionDynamicAnalysis",
    "PartToPartShearCouplingDynamicAnalysis",
    "PartToPartShearCouplingHalfDynamicAnalysis",
    "PlanetaryConnectionDynamicAnalysis",
    "PlanetaryGearSetDynamicAnalysis",
    "PlanetCarrierDynamicAnalysis",
    "PointLoadDynamicAnalysis",
    "PowerLoadDynamicAnalysis",
    "PulleyDynamicAnalysis",
    "RingPinsDynamicAnalysis",
    "RingPinsToDiscConnectionDynamicAnalysis",
    "RollingRingAssemblyDynamicAnalysis",
    "RollingRingConnectionDynamicAnalysis",
    "RollingRingDynamicAnalysis",
    "RootAssemblyDynamicAnalysis",
    "ShaftDynamicAnalysis",
    "ShaftHubConnectionDynamicAnalysis",
    "ShaftToMountableComponentConnectionDynamicAnalysis",
    "SpecialisedAssemblyDynamicAnalysis",
    "SpiralBevelGearDynamicAnalysis",
    "SpiralBevelGearMeshDynamicAnalysis",
    "SpiralBevelGearSetDynamicAnalysis",
    "SpringDamperConnectionDynamicAnalysis",
    "SpringDamperDynamicAnalysis",
    "SpringDamperHalfDynamicAnalysis",
    "StraightBevelDiffGearDynamicAnalysis",
    "StraightBevelDiffGearMeshDynamicAnalysis",
    "StraightBevelDiffGearSetDynamicAnalysis",
    "StraightBevelGearDynamicAnalysis",
    "StraightBevelGearMeshDynamicAnalysis",
    "StraightBevelGearSetDynamicAnalysis",
    "StraightBevelPlanetGearDynamicAnalysis",
    "StraightBevelSunGearDynamicAnalysis",
    "SynchroniserDynamicAnalysis",
    "SynchroniserHalfDynamicAnalysis",
    "SynchroniserPartDynamicAnalysis",
    "SynchroniserSleeveDynamicAnalysis",
    "TorqueConverterConnectionDynamicAnalysis",
    "TorqueConverterDynamicAnalysis",
    "TorqueConverterPumpDynamicAnalysis",
    "TorqueConverterTurbineDynamicAnalysis",
    "UnbalancedMassDynamicAnalysis",
    "VirtualComponentDynamicAnalysis",
    "WormGearDynamicAnalysis",
    "WormGearMeshDynamicAnalysis",
    "WormGearSetDynamicAnalysis",
    "ZerolBevelGearDynamicAnalysis",
    "ZerolBevelGearMeshDynamicAnalysis",
    "ZerolBevelGearSetDynamicAnalysis",
)



"""FEPartLoadCase"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal.implicit import list_with_selected_item
from mastapy._internal import constructor, conversion
from mastapy.system_model.fe import _2383
from mastapy.system_model.analyses_and_results.static_loads import _6809
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_FE_PART_LOAD_CASE = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads", "FEPartLoadCase"
)

if TYPE_CHECKING:
    from mastapy.system_model.fe import _2359
    from mastapy.system_model.part_model import _2453
    from mastapy.system_model.analyses_and_results.static_loads import (
        _6836,
        _6838,
        _6929,
    )
    from mastapy.system_model.analyses_and_results import _2657, _2653, _2651


__docformat__ = "restructuredtext en"
__all__ = ("FEPartLoadCase",)


Self = TypeVar("Self", bound="FEPartLoadCase")


class FEPartLoadCase(_6809.AbstractShaftOrHousingLoadCase):
    """FEPartLoadCase

    This is a mastapy class.
    """

    TYPE = _FE_PART_LOAD_CASE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_FEPartLoadCase")

    class _Cast_FEPartLoadCase:
        """Special nested class for casting FEPartLoadCase to subclasses."""

        def __init__(
            self: "FEPartLoadCase._Cast_FEPartLoadCase", parent: "FEPartLoadCase"
        ):
            self._parent = parent

        @property
        def abstract_shaft_or_housing_load_case(
            self: "FEPartLoadCase._Cast_FEPartLoadCase",
        ) -> "_6809.AbstractShaftOrHousingLoadCase":
            return self._parent._cast(_6809.AbstractShaftOrHousingLoadCase)

        @property
        def component_load_case(
            self: "FEPartLoadCase._Cast_FEPartLoadCase",
        ) -> "_6838.ComponentLoadCase":
            from mastapy.system_model.analyses_and_results.static_loads import _6838

            return self._parent._cast(_6838.ComponentLoadCase)

        @property
        def part_load_case(
            self: "FEPartLoadCase._Cast_FEPartLoadCase",
        ) -> "_6929.PartLoadCase":
            from mastapy.system_model.analyses_and_results.static_loads import _6929

            return self._parent._cast(_6929.PartLoadCase)

        @property
        def part_analysis(
            self: "FEPartLoadCase._Cast_FEPartLoadCase",
        ) -> "_2657.PartAnalysis":
            from mastapy.system_model.analyses_and_results import _2657

            return self._parent._cast(_2657.PartAnalysis)

        @property
        def design_entity_single_context_analysis(
            self: "FEPartLoadCase._Cast_FEPartLoadCase",
        ) -> "_2653.DesignEntitySingleContextAnalysis":
            from mastapy.system_model.analyses_and_results import _2653

            return self._parent._cast(_2653.DesignEntitySingleContextAnalysis)

        @property
        def design_entity_analysis(
            self: "FEPartLoadCase._Cast_FEPartLoadCase",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def fe_part_load_case(
            self: "FEPartLoadCase._Cast_FEPartLoadCase",
        ) -> "FEPartLoadCase":
            return self._parent

        def __getattr__(self: "FEPartLoadCase._Cast_FEPartLoadCase", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "FEPartLoadCase.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def active_angle_index(
        self: Self,
    ) -> "list_with_selected_item.ListWithSelectedItem_int":
        """ListWithSelectedItem[int]"""
        temp = self.wrapped.ActiveAngleIndex

        if temp is None:
            return 0

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_int",
        )(temp)

    @active_angle_index.setter
    @enforce_parameter_types
    def active_angle_index(self: Self, value: "int"):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_int.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_int.implicit_type()
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0
        )
        self.wrapped.ActiveAngleIndex = value

    @property
    def angle(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Angle

        if temp is None:
            return 0.0

        return temp

    @angle.setter
    @enforce_parameter_types
    def angle(self: Self, value: "float"):
        self.wrapped.Angle = float(value) if value is not None else 0.0

    @property
    def angle_source(self: Self) -> "_2359.AngleSource":
        """mastapy.system_model.fe.AngleSource

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AngleSource

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.SystemModel.FE.AngleSource"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy.system_model.fe._2359", "AngleSource"
        )(value)

    @property
    def fe_substructure(
        self: Self,
    ) -> "list_with_selected_item.ListWithSelectedItem_FESubstructure":
        """ListWithSelectedItem[mastapy.system_model.fe.FESubstructure]"""
        temp = self.wrapped.FESubstructure

        if temp is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_FESubstructure",
        )(temp)

    @fe_substructure.setter
    @enforce_parameter_types
    def fe_substructure(self: Self, value: "_2383.FESubstructure"):
        wrapper_type = (
            list_with_selected_item.ListWithSelectedItem_FESubstructure.wrapper_type()
        )
        enclosed_type = (
            list_with_selected_item.ListWithSelectedItem_FESubstructure.implicit_type()
        )
        value = wrapper_type[enclosed_type](
            value.wrapped if value is not None else None
        )
        self.wrapped.FESubstructure = value

    @property
    def mass_scaling_factor(self: Self) -> "float":
        """float"""
        temp = self.wrapped.MassScalingFactor

        if temp is None:
            return 0.0

        return temp

    @mass_scaling_factor.setter
    @enforce_parameter_types
    def mass_scaling_factor(self: Self, value: "float"):
        self.wrapped.MassScalingFactor = float(value) if value is not None else 0.0

    @property
    def override_default_fe_substructure(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.OverrideDefaultFESubstructure

        if temp is None:
            return False

        return temp

    @override_default_fe_substructure.setter
    @enforce_parameter_types
    def override_default_fe_substructure(self: Self, value: "bool"):
        self.wrapped.OverrideDefaultFESubstructure = (
            bool(value) if value is not None else False
        )

    @property
    def stiffness_scaling_factor(self: Self) -> "float":
        """float"""
        temp = self.wrapped.StiffnessScalingFactor

        if temp is None:
            return 0.0

        return temp

    @stiffness_scaling_factor.setter
    @enforce_parameter_types
    def stiffness_scaling_factor(self: Self, value: "float"):
        self.wrapped.StiffnessScalingFactor = float(value) if value is not None else 0.0

    @property
    def component_design(self: Self) -> "_2453.FEPart":
        """mastapy.system_model.part_model.FEPart

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def planetaries(self: Self) -> "List[FEPartLoadCase]":
        """List[mastapy.system_model.analyses_and_results.static_loads.FEPartLoadCase]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Planetaries

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def surfaces_for_data_logging(
        self: Self,
    ) -> "List[_6836.CMSElementFaceGroupWithSelectionOption]":
        """List[mastapy.system_model.analyses_and_results.static_loads.CMSElementFaceGroupWithSelectionOption]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SurfacesForDataLogging

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: Self) -> "FEPartLoadCase._Cast_FEPartLoadCase":
        return self._Cast_FEPartLoadCase(self)



"""TableAndChartOptions"""
from __future__ import annotations

from typing import TypeVar, Any
from enum import Enum

from mastapy._internal.python_net import python_net_import

_TABLE_AND_CHART_OPTIONS = python_net_import(
    "SMT.MastaAPI.Utility.Enums", "TableAndChartOptions"
)


__docformat__ = "restructuredtext en"
__all__ = ("TableAndChartOptions",)


Self = TypeVar("Self", bound="TableAndChartOptions")


class TableAndChartOptions(Enum):
    """TableAndChartOptions

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls):
        return _TABLE_AND_CHART_OPTIONS

    CHART_THEN_TABLE = 0
    TABLE_THEN_CHART = 1
    TABLE = 2
    CHART = 3


def __enum_setattr(self: Self, attr: str, value: Any):
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: Self, attr: str):
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


TableAndChartOptions.__setattr__ = __enum_setattr
TableAndChartOptions.__delattr__ = __enum_delattr



"""JournalBearingType"""
from __future__ import annotations

from typing import TypeVar, Any
from enum import Enum

from mastapy._internal.python_net import python_net_import

_JOURNAL_BEARING_TYPE = python_net_import("SMT.MastaAPI.Bearings", "JournalBearingType")


__docformat__ = "restructuredtext en"
__all__ = ("JournalBearingType",)


Self = TypeVar("Self", bound="JournalBearingType")


class JournalBearingType(Enum):
    """JournalBearingType

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls):
        return _JOURNAL_BEARING_TYPE

    PLAIN_OIL_FED = 0
    PLAIN_GREASE_FILLED = 1


def __enum_setattr(self: Self, attr: str, value: Any):
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: Self, attr: str):
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


JournalBearingType.__setattr__ = __enum_setattr
JournalBearingType.__delattr__ = __enum_delattr
